@@ -242,7 +242,6 @@ def get_unit_by_imei(imei: str, session: WialonSession) -> WialonUnit | None:
                 "propValueMask": imei,
                 "sortType": "sys_unique_id",
                 "propType": "property",
-                "or_logic": 0,
             },
             "force": 0,
             "flags": flags.DataFlag.UNIT_BASE,
@@ -251,7 +250,6 @@ def get_unit_by_imei(imei: str, session: WialonSession) -> WialonUnit | None:
         }
     )
 
-    print(f"{results = }")
     if results and results.get("totalItemsCount", 0) == 1:
         return WialonUnit(id=results["items"][0]["id"], session=session)
 
